@@ -161,7 +161,7 @@ sub apply_methods {
 
             Carp::cluck(sprintf
                   q{Due to %s in roles %s,}
-                . q{ the behavior of method%s %s mihgt be incompatible with Moose}
+                . q{ the behavior of method%s %s might be incompatible with Moose}
                 . q{, check out %s},
                     $method_name_conflict,
                     $roles,
@@ -185,7 +185,7 @@ Mouse::Meta::Role::Composite - An object to represent the set of roles
 
 =head1 VERSION
 
-This document describes Mouse version 2.4.2
+This document describes Mouse version v2.4.3
 
 =head1 SEE ALSO
 
